@@ -38,11 +38,11 @@ _pkg_config = {
     'py_version':         0x030403,
     'qt_framework':       0,
     'sip_bin':            '/usr/lib/python3.4/site-packages/sip',
-    'sip_config_args':    '-p cygwin-g++ -b /usr/lib/python3.4/site-packages -d /usr/lib/python3.4/site-packages -e /usr/include/python3.4m -v /usr/share/python3-sip CFLAGS+=-ggdb -O2 -pipe -Wimplicit-function-declaration -fdebug-prefix-map=/usr/src/ports/python3-sip/python3-sip-4.16.8-1.i686/build=/usr/src/debug/python3-sip-4.16.8-1 -fdebug-prefix-map=/usr/src/ports/python3-sip/python3-sip-4.16.8-1.i686/src/sip-4.16.8=/usr/src/debug/python3-sip-4.16.8-1 CXXFLAGS+=-ggdb -O2 -pipe -fdebug-prefix-map=/usr/src/ports/python3-sip/python3-sip-4.16.8-1.i686/build=/usr/src/debug/python3-sip-4.16.8-1 -fdebug-prefix-map=/usr/src/ports/python3-sip/python3-sip-4.16.8-1.i686/src/sip-4.16.8=/usr/src/debug/python3-sip-4.16.8-1',
+    'sip_config_args':    '-p cygwin-g++ -b /usr/lib/python3.4/site-packages -d /usr/lib/python3.4/site-packages -e /usr/include/python3.4m -v /usr/share/python3-sip CFLAGS+=-ggdb -O2 -pipe -Wimplicit-function-declaration -fdebug-prefix-map=/usr/src/ports/python3-sip/python3-sip-4.16.9-1.x86_64/build=/usr/src/debug/python3-sip-4.16.9-1 -fdebug-prefix-map=/usr/src/ports/python3-sip/python3-sip-4.16.9-1.x86_64/src/sip-4.16.9=/usr/src/debug/python3-sip-4.16.9-1 CXXFLAGS+=-ggdb -O2 -pipe -fdebug-prefix-map=/usr/src/ports/python3-sip/python3-sip-4.16.9-1.x86_64/build=/usr/src/debug/python3-sip-4.16.9-1 -fdebug-prefix-map=/usr/src/ports/python3-sip/python3-sip-4.16.9-1.x86_64/src/sip-4.16.9=/usr/src/debug/python3-sip-4.16.9-1',
     'sip_inc_dir':        '/usr/include/python3.4m',
     'sip_mod_dir':        '/usr/lib/python3.4/site-packages',
-    'sip_version':        0x041008,
-    'sip_version_str':    '4.16.8',
+    'sip_version':        0x041009,
+    'sip_version_str':    '4.16.9',
     'universal':          ''
 }
 
@@ -50,7 +50,7 @@ _default_macros = {
     'AIX_SHLIB':                '',
     'AR':                       'ar cqs',
     'CC':                       'gcc',
-    'CFLAGS':                   '-pipe -ggdb -O2 -pipe -Wimplicit-function-declaration -fdebug-prefix-map=/usr/src/ports/python3-sip/python3-sip-4.16.8-1.i686/build=/usr/src/debug/python3-sip-4.16.8-1 -fdebug-prefix-map=/usr/src/ports/python3-sip/python3-sip-4.16.8-1.i686/src/sip-4.16.8=/usr/src/debug/python3-sip-4.16.8-1',
+    'CFLAGS':                   '-pipe -ggdb -O2 -pipe -Wimplicit-function-declaration -fdebug-prefix-map=/usr/src/ports/python3-sip/python3-sip-4.16.9-1.x86_64/build=/usr/src/debug/python3-sip-4.16.9-1 -fdebug-prefix-map=/usr/src/ports/python3-sip/python3-sip-4.16.9-1.x86_64/src/sip-4.16.9=/usr/src/debug/python3-sip-4.16.9-1',
     'CFLAGS_APP':               '',
     'CFLAGS_CONSOLE':           '',
     'CFLAGS_DEBUG':             '-g',
@@ -73,7 +73,7 @@ _default_macros = {
     'CONFIG':                   'qt warn_on release incremental link_prl',
     'COPY':                     'cp -f',
     'CXX':                      'g++',
-    'CXXFLAGS':                 '-pipe -ggdb -O2 -pipe -fdebug-prefix-map=/usr/src/ports/python3-sip/python3-sip-4.16.8-1.i686/build=/usr/src/debug/python3-sip-4.16.8-1 -fdebug-prefix-map=/usr/src/ports/python3-sip/python3-sip-4.16.8-1.i686/src/sip-4.16.8=/usr/src/debug/python3-sip-4.16.8-1',
+    'CXXFLAGS':                 '-pipe -ggdb -O2 -pipe -fdebug-prefix-map=/usr/src/ports/python3-sip/python3-sip-4.16.9-1.x86_64/build=/usr/src/debug/python3-sip-4.16.9-1 -fdebug-prefix-map=/usr/src/ports/python3-sip/python3-sip-4.16.9-1.x86_64/src/sip-4.16.9=/usr/src/debug/python3-sip-4.16.9-1',
     'CXXFLAGS_APP':             '',
     'CXXFLAGS_CONSOLE':         '',
     'CXXFLAGS_DEBUG':           '-g',
